@@ -109,7 +109,7 @@ class Tts(TwoToneSpectroscopy):
 
     def run_measurements(self, *, x_key: Union[float, int, Iterable] = None, y_key: Union[float, int, Iterable] = None,
                          x_min=None, x_max=None, y_min=None, y_max=None,
-                         sleep=0.007):
+                         sleep=0.007, timeout=None):
 
         self.iter_setup(x_key=x_key, y_key=y_key,
                         x_min=x_min, x_max=x_max, y_min=y_min, y_max=y_max)
@@ -123,6 +123,10 @@ class Tts(TwoToneSpectroscopy):
             for i in range(len(self.load)):
                 if (i == 0) or (self.load[i] != self.load[i - 1]):
                     self.LO_res.set_center(float(self.__find_resonator))
+                    if timeout is not None:
+                        timer.sleep(timeout)
+                    else:
+                        pass
 
                 self.hdawg.setDouble(self.hdawg_setDouble, self.load[i])  # Current write
                 self.LO.set_frequency(self.frequency[i])  # Frequency write
